import os
import codecs
import re

languages = os.listdir('../../localisation/')

ord_regex = re.compile("^([^#]*sequential_name)\s*=\s*\"(.*\%O\%.*)\"(.*)$")
seq_regex = re.compile("^([^#]*sequential_name)\s*=\s*\"(.*\%C\%.*)\"(.*)$")
content_regex = re.compile("\s*([^\s]*)\s*=\s*{")

localisation_files_output = []

if __name__=="__main__":
	for filename in os.listdir():
		parts = filename.split('.')
		if parts[-1] == 'txt':
			namelist = parts[0].upper()
			output_lines = []
			with open(filename, "r", encoding='utf-8') as namelist_file:
				print(f"Processing namelist: {namelist}")
				lines = namelist_file.readlines()
				localisation_output = []
				curr_layer = []
				for i in range(len(lines)):
					line = lines[i]
					actual_line = line.split('#')[0]
					bracket_match = content_regex.match(actual_line)
					if bracket_match is not None:
						curr_layer.append(bracket_match.groups()[0].strip())
					if '}' in actual_line:
						curr_layer = curr_layer[:-1]

					ord_match = ord_regex.match(actual_line)
					if ord_match is not None:
						ord_groups = ord_match.groups()
						group_key = curr_layer[-1].upper().replace('_', '')
						loc_key = f"{namelist}_xx{group_key}_ORD"
						loc_text = ord_groups[1].replace('%', '$')
						print(f"Assigning loc key {loc_key} as text: {loc_text}")
						output_lines.append(f"{ord_groups[0]} = {loc_key}{ord_groups[2]}\n")
						localisation_output.append((loc_key, loc_text))
						continue
					else:
						seq_match = seq_regex.match(actual_line)
						if seq_match is not None:
							seq_groups = seq_match.groups()
							group_key = curr_layer[-1].upper().replace('_', '')
							loc_key = f"{namelist}_{group_key}xx_SEQ"
							loc_text = seq_groups[1].replace('%', '$')
							print(f"Assigning loc key {loc_key} as text: {loc_text}")
							output_lines.append(f"{ord_groups[0]} = {loc_key}{seq_groups[2]}\n")
							localisation_output.append((loc_key, loc_text))
							continue
					output_lines.append(line)
				localisation_files_output.append((namelist, localisation_output))
			with open(filename, "w", encoding='utf-8') as namelist_file:
				namelist_file.writelines(output_lines)

	for localisation_file_spec in localisation_files_output:
		for language in languages:
			filename = f"../../localisation/{language}/name_list_{localisation_file_spec[0]}_l_{language}.yml"
			with codecs.open(filename, 'w', 'utf-8') as localisation_file:
				localisation_file.write(u'\ufeff')
				localisation_file.write(f'l_{language}:\n')
				loc_pairs = localisation_file_spec[1]
				for pair in loc_pairs:
					localisation_file.write(f' {pair[0]}:0 "{pair[1]}"\n')